import React, { ChangeEvent, FC, useEffect, useState } from 'react';
import Paper from '@mui/material/Paper';
import Typography from '@mui/material/Typography';
import Box from '@mui/material/Box';
import TextField from '@mui/material/TextField';

export const GlipSender: FC<{
  debug?: boolean
  value: { clientId: string; clientSecret: string; message: string };
  onChange: (value: {
    clientId: string; clientSecret: string; message: string
  }) => void
}> = ({ value, debug, onChange }) => {
  const handleChange = (e: ChangeEvent<HTMLInputElement>) => {
    onChange({
      ...value,
      [e.target.name]: e.target.value
    });
  };
  return (
    <Paper sx={{ p: 2, mb: 2 }}>
      <Typography variant="subtitle1">GlipSender</Typography>
      <Typography variant="caption" component="div" sx={{ mb: 1 }}>
        WFL Hub will send messages via <a style={{ color: '#f50057' }}
                                          href="https://developers.ringcentral.com/guide/team-messaging/bots/walkthrough"
                                          target="_blank" rel="noreferrer">RingCentral Bot</a>, please fill in:
      </Typography>
      <Box>
        {!debug &&
          <>
            <TextField label="RingCentral Bot Client ID" fullWidth name="clientId" onChange={handleChange}
                       value={value.clientId} sx={{ mb: 4 }}/>
            <TextField label="RingCentral Bot Client Secret" sx={{ mb: 4 }}
                       value={value.clientSecret} name="clientSecret" fullWidth onChange={handleChange}
            />
          </>}
        <TextField label="Message format" placeholder="Please enter your message format"
                   value={value.message} name="message" fullWidth
                   onChange={handleChange} maxRows={5} minRows={2} multiline
        />
      </Box>
    </Paper>
  );
};
